pub struct BaggageEntry {
pub key: String,
pub value: String,
}Expand description
A single baggage entry (key-value pair).
Fields
key: Stringvalue: StringTrait Implementations
Sourceimpl Clone for BaggageEntry
impl Clone for BaggageEntry
Sourcefn clone(&self) -> BaggageEntry
fn clone(&self) -> BaggageEntry
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for BaggageEntry
impl Debug for BaggageEntry
Sourceimpl<'de> Deserialize<'de> for BaggageEntry
impl<'de> Deserialize<'de> for BaggageEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for BaggageEntry
impl Hash for BaggageEntry
Sourceimpl JsonSchema for BaggageEntry
impl JsonSchema for BaggageEntry
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BaggageEntry
impl PartialEq for BaggageEntry
Sourcefn eq(&self, other: &BaggageEntry) -> bool
fn eq(&self, other: &BaggageEntry) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for BaggageEntry
impl Serialize for BaggageEntry
impl Eq for BaggageEntry
impl StructuralPartialEq for BaggageEntry