pub struct ToolEffectDispatchReceiptId(pub String);Expand description
Opaque identifier for a tool effect dispatch receipt artifact.
Tuple Fields
0: StringImplementations
Sourceimpl ToolEffectDispatchReceiptId
impl ToolEffectDispatchReceiptId
Sourcepub fn new(value: impl Into<String>) -> Self
pub fn new(value: impl Into<String>) -> Self
Creates an ID from a canonical family-qualified string or a validated payload that will be family-qualified.
Panics when the value is empty, non-canonical, or belongs to a different ID family. Use try_new for untrusted input.