pub struct ContradictionWitnessId(pub String);Expand description
Opaque identifier for one contradiction-witness artifact.
Used to point at a stored explanation of why a claim is simultaneously supported and refuted within one semantics profile.
Tuple Fields
0: StringImplementations